==> uppy__provider-views-4.0.2.jar: META-INF/resources/webjars/uppy__provider-views/4.0.2/CHANGELOG.md <==
# @uppy/provider-views

## 4.0.2

Released: 2024-10-31
Included in: Uppy v4.6.0

- @uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react-native,@uppy/react,@uppy/redux-dev-tools,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: Fix links (Anthony Veaudry / #5492)

## 4.0.0

Released: 2024-07-10
Included in: Uppy v4.0.0

- @uppy/provider-views: `.openFolder()` - return progress indication (Evgenia Karunus / #5306)

## 4.0.0-beta.11

Released: 2024-07-02
Included in: Uppy v4.0.0-beta.14

- @uppy/provider-views: `afterFill()` - add loading progress (Evgenia Karunus / #5288)

## 4.0.0-beta.10

Released: 2024-06-27
Included in: Uppy v4.0.0-beta.13

- @uppy/provider-views: `Loader.tsx` - delete the file (Evgenia Karunus / #5284)
- @uppy/provider-views: Provider views rewrite (.files, .folders => .partialTree) (Evgenia Karunus / #5050)

## 4.0.0-beta.9

Released: 2024-06-18
Included in: Uppy v4.0.0-beta.12

- @uppy/provider-views: Renames & `eslint-disable react/require-default-props` removal (Evgenia Karunus / #5251)
- examples,@uppy/locales,@uppy/provider-views,@uppy/transloadit: Release: uppy@3.26.1 (github-actions[bot] / #5242)
- @uppy/provider-views: fix wrong font for files (Merlijn Vos / #5234)

## 4.0.0-beta.7

Released: 2024-06-04
Included in: Uppy v4.0.0-beta.10

- @uppy/provider-views: PartialTree - get rid of `.onFirstRender()` (Evgenia Karunus / #5187)

## 4.0.0-beta.4

Released: 2024-04-29
Included in: Uppy v4.0.0-beta.4

- @uppy/dashboard,@uppy/provider-views: Remove JSX global type everywhere (Merlijn Vos / #5117)
- @uppy/provider-views: bring back "loaded X files..." (Mikael Finstad / #5097)

## 4.0.0-beta.1

Released: 2024-03-28
Included in: Uppy v4.0.0-beta.1

- @uppy/companion-client,@uppy/provider-views,@uppy/status-bar: fix type imports (Antoine du Hamel / #5038)
- @uppy/provider-views: fix `super.toggleCheckbox` bug (Mikael Finstad / #5004)
- @uppy/core,@uppy/provider-views: Fix breadcrumbs (Evgenia Karunus / #4986)

## 3.12.1

Released: 2024-06-11
Included in: Uppy v3.26.1

- @uppy/provider-views: fix wrong font for files (Merlijn Vos / #5234)

## 3.12.0

Released: 2024-04-29
Included in: Uppy v3.25.0

- @uppy/dashboard,@uppy/provider-views: Remove JSX global type everywhere (Merlijn Vos / #5117)
- @uppy/provider-views: bring back "loaded X files..." (Mikael Finstad / #5097)

## 3.11.0

Released: 2024-03-27
Included in: Uppy v3.24.0

- @uppy/box,@uppy/companion-client,@uppy/provider-views,@uppy/status-bar: fix type imports (Antoine du Hamel / #5038)
- @uppy/provider-views: fix `super.toggleCheckbox` bug (Mikael Finstad / #5004)
- @uppy/core,@uppy/provider-views: Fix breadcrumbs (Evgenia Karunus / #4986)

## 3.10.0

Released: 2024-02-28
Included in: Uppy v3.23.0

- @uppy/provider-views: migrate to TS (Merlijn Vos / #4919)

## 3.9.0

Released: 2024-02-19
Included in: Uppy v3.22.0

- @uppy/provider-views: update uppy-providerbrowser-viewtype--list.scss (aditya patadia / #4913)
- @uppy/provider-views: add referrerpolicy to images (merlijn vos / #4853)

## 3.8.0

Released: 2023-12-12
Included in: Uppy v3.21.0

- @uppy/provider-views: fix uploadRemoteFile undefined (Mikael Finstad / #4814)

## 3.5.0

Released: 2023-08-15
Included in: Uppy v3.14.0

- @uppy/companion-client,@uppy/provider-views: make authentication optional (Dominik Schmidt / #4556)
- @uppy/provider-views: fix ProviderView error on empty plugin.icon (Dominik Schmidt / #4553)

## 3.4.1

Released: 2023-07-20
Included in: Uppy v3.13.0

- @uppy/provider-views: Add VirtualList to ProviderView (Merlijn Vos / #4566)
- @uppy/provider-views: fix race conditions with folder loading (Mikael Finstad / #4578)
- @uppy/provider-views: fix infinite folder loading  (Mikael Finstad / #4590)

## 3.4.0

Released: 2023-07-13
Included in: Uppy v3.12.0

- @uppy/provider-views: add support for remote file paths (Mikael Finstad / #4537)
- @uppy/box,@uppy/companion,@uppy/dropbox,@uppy/google-drive,@uppy/onedrive,@uppy/provider-views: Load Google Drive / OneDrive lists 5-10x faster & always load all files (Merlijn Vos / #4513)

## 3.3.1

Released: 2023-06-19
Included in: Uppy v3.10.0

- @uppy/provider-views: Fix range selection not resetting and computing correctly (Terence C / #4415)

## 3.3.0

Released: 2023-04-18
Included in: Uppy v3.8.0

- @uppy/provider-views: Concurrent file listing (Mikael Finstad / #4401)
- @uppy/core,@uppy/locales,@uppy/provider-views: User feedback adding recursive folders take 2 (Mikael Finstad / #4399)

## 3.2.0

Released: 2023-04-04
Included in: Uppy v3.7.0

- @uppy/provider-views: fix race condition when adding folders (Mikael Finstad / #4384)
- @uppy/provider-views: UI: Use form attribite with a form in doc root to prevent outer form submit (Artur Paikin / #4283)

## 3.0.2

Released: 2022-10-24
Included in: Uppy v3.2.2

- @uppy/provider-views: Fix button and input inconsistent font and style (Artur Paikin / #4162)

## 3.0.1

Released: 2022-09-25
Included in: Uppy v3.1.0

- @uppy/audio,@uppy/aws-s3-multipart,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/companion,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/redux-dev-tools,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: add missing entries to changelog for individual packages (Antoine du Hamel / #4092)

## 3.0.0-beta.3

Released: 2022-08-16
Included in: Uppy v3.0.0-beta.5

- @uppy/provider-views: Reset filter input correctly in provider views (Merlijn Vos / #3978)
- @uppy/provider-views: core validateRestrictions: return error directly vs the result/reason obj (Artur Paikin / #3951)

## 2.1.2

Released: 2022-07-06
Included in: Uppy v2.12.2

- @uppy/provider-views: improve logging (Mikael Finstad / #3638)

## 2.1.1

Released: 2022-05-30
Included in: Uppy v2.11.0

- @uppy/provider-views: Add onKeyPress event handler to capture e.shiftKey, unavailable in onChange (Artur Paikin / #3768)

## 2.1.0

Released: 2022-05-14
Included in: Uppy v2.10.0

- @uppy/provider-views: refactor to ESM (Antoine du Hamel / #3715)

## 2.0.8

Released: 2022-03-16
Included in: Uppy v2.8.0

- @uppy/provider-views: provider-view: fix breadcrumbs (Artur Paikin / #3535)

## 2.0.7

Released: 2022-02-14
Included in: Uppy v2.5.0

- @uppy/companion-client,@uppy/companion,@uppy/provider-views,@uppy/robodog: Finishing touches on Companion dynamic Oauth (Renée Kooi / #2802)
- @uppy/provider-views: Unsplash: UI improvements (Artur Paikin / #3438)
## 3.0.0

Released: 2022-08-22
Included in: Uppy v3.0.0

- Switch to ESM

==> uppy__provider-views-4.4.3.jar: META-INF/resources/webjars/uppy__provider-views/4.4.3/CHANGELOG.md <==
# @uppy/provider-views

## 4.4.3

Released: 2025-04-14
Included in: Uppy v4.15.0

- @uppy/provider-views: Fix google photos picker (Mikael Finstad / #5717)

## 4.4.2

Released: 2025-02-03
Included in: Uppy v4.13.2

- @uppy/provider-views: fix google photos picker videos (Mikael Finstad / #5635)
- @uppy/core,@uppy/google-drive-picker,@uppy/google-photos-picker,@uppy/provider-views:

## 4.4.1

Released: 2025-01-09
Included in: Uppy v4.12.2

- @uppy/provider-views: Import types consistently from @uppy/core (Merlijn Vos / #5589)
- @uppy/provider-views: fix incorrect import (Merlijn Vos / #5588)

## 4.4.0

Released: 2025-01-08
Included in: Uppy v4.12.0

- @uppy/unsplash,@uppy/provider-views: add utmSource option (Merlijn Vos / #5580)

## 4.3.0

Released: 2025-01-06
Included in: Uppy v4.11.0

- @uppy/angular,@uppy/audio,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive-picker,@uppy/google-drive,@uppy/google-photos-picker,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/vue,@uppy/webcam,@uppy/webdav,@uppy/xhr-upload,@uppy/zoom: Remove "paths" from all tsconfig's (Merlijn Vos / #5572)

## 4.2.1

Released: 2025-01-06
Included in: Uppy v4.10.0

- @uppy/core,@uppy/dashboard,@uppy/provider-views,@uppy/store-redux,@uppy/url: build(deps): bump nanoid from 5.0.7 to 5.0.9 (dependabot[bot] / #5544)

## 4.1.0

Released: 2024-12-05
Included in: Uppy v4.8.0

- @uppy/provider-views: Google picker scope (Mikael Finstad / #5535)
- @uppy/core,@uppy/provider-views: move useStore out of core (Mikael Finstad / #5533)
- @uppy/audio,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: cleanup tsconfig (Mikael Finstad / #5520)

## 4.0.2

Released: 2024-10-31
Included in: Uppy v4.6.0

- @uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react-native,@uppy/react,@uppy/redux-dev-tools,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: Fix links (Anthony Veaudry / #5492)

## 4.0.0

Released: 2024-07-10
Included in: Uppy v4.0.0

- @uppy/provider-views: `.openFolder()` - return progress indication (Evgenia Karunus / #5306)

## 4.0.0-beta.11

Released: 2024-07-02
Included in: Uppy v4.0.0-beta.14

- @uppy/provider-views: `afterFill()` - add loading progress (Evgenia Karunus / #5288)

## 4.0.0-beta.10

Released: 2024-06-27
Included in: Uppy v4.0.0-beta.13

- @uppy/provider-views: `Loader.tsx` - delete the file (Evgenia Karunus / #5284)
- @uppy/provider-views: Provider views rewrite (.files, .folders => .partialTree) (Evgenia Karunus / #5050)

## 4.0.0-beta.9

Released: 2024-06-18
Included in: Uppy v4.0.0-beta.12

- @uppy/provider-views: Renames & `eslint-disable react/require-default-props` removal (Evgenia Karunus / #5251)
- examples,@uppy/locales,@uppy/provider-views,@uppy/transloadit: Release: uppy@3.26.1 (github-actions[bot] / #5242)
- @uppy/provider-views: fix wrong font for files (Merlijn Vos / #5234)

## 4.0.0-beta.7

Released: 2024-06-04
Included in: Uppy v4.0.0-beta.10

- @uppy/provider-views: PartialTree - get rid of `.onFirstRender()` (Evgenia Karunus / #5187)

## 4.0.0-beta.4

Released: 2024-04-29
Included in: Uppy v4.0.0-beta.4

- @uppy/dashboard,@uppy/provider-views: Remove JSX global type everywhere (Merlijn Vos / #5117)
- @uppy/provider-views: bring back "loaded X files..." (Mikael Finstad / #5097)

## 4.0.0-beta.1

Released: 2024-03-28
Included in: Uppy v4.0.0-beta.1

- @uppy/companion-client,@uppy/provider-views,@uppy/status-bar: fix type imports (Antoine du Hamel / #5038)
- @uppy/provider-views: fix `super.toggleCheckbox` bug (Mikael Finstad / #5004)
- @uppy/core,@uppy/provider-views: Fix breadcrumbs (Evgenia Karunus / #4986)

## 3.12.1

Released: 2024-06-11
Included in: Uppy v3.26.1

- @uppy/provider-views: fix wrong font for files (Merlijn Vos / #5234)

## 3.12.0

Released: 2024-04-29
Included in: Uppy v3.25.0

- @uppy/dashboard,@uppy/provider-views: Remove JSX global type everywhere (Merlijn Vos / #5117)
- @uppy/provider-views: bring back "loaded X files..." (Mikael Finstad / #5097)

## 3.11.0

Released: 2024-03-27
Included in: Uppy v3.24.0

- @uppy/box,@uppy/companion-client,@uppy/provider-views,@uppy/status-bar: fix type imports (Antoine du Hamel / #5038)
- @uppy/provider-views: fix `super.toggleCheckbox` bug (Mikael Finstad / #5004)
- @uppy/core,@uppy/provider-views: Fix breadcrumbs (Evgenia Karunus / #4986)

## 3.10.0

Released: 2024-02-28
Included in: Uppy v3.23.0

- @uppy/provider-views: migrate to TS (Merlijn Vos / #4919)

## 3.9.0

Released: 2024-02-19
Included in: Uppy v3.22.0

- @uppy/provider-views: update uppy-providerbrowser-viewtype--list.scss (aditya patadia / #4913)
- @uppy/provider-views: add referrerpolicy to images (merlijn vos / #4853)

## 3.8.0

Released: 2023-12-12
Included in: Uppy v3.21.0

- @uppy/provider-views: fix uploadRemoteFile undefined (Mikael Finstad / #4814)

## 3.5.0

Released: 2023-08-15
Included in: Uppy v3.14.0

- @uppy/companion-client,@uppy/provider-views: make authentication optional (Dominik Schmidt / #4556)
- @uppy/provider-views: fix ProviderView error on empty plugin.icon (Dominik Schmidt / #4553)

## 3.4.1

Released: 2023-07-20
Included in: Uppy v3.13.0

- @uppy/provider-views: Add VirtualList to ProviderView (Merlijn Vos / #4566)
- @uppy/provider-views: fix race conditions with folder loading (Mikael Finstad / #4578)
- @uppy/provider-views: fix infinite folder loading  (Mikael Finstad / #4590)

## 3.4.0

Released: 2023-07-13
Included in: Uppy v3.12.0

- @uppy/provider-views: add support for remote file paths (Mikael Finstad / #4537)
- @uppy/box,@uppy/companion,@uppy/dropbox,@uppy/google-drive,@uppy/onedrive,@uppy/provider-views: Load Google Drive / OneDrive lists 5-10x faster & always load all files (Merlijn Vos / #4513)

## 3.3.1

Released: 2023-06-19
Included in: Uppy v3.10.0

- @uppy/provider-views: Fix range selection not resetting and computing correctly (Terence C / #4415)

## 3.3.0

Released: 2023-04-18
Included in: Uppy v3.8.0

- @uppy/provider-views: Concurrent file listing (Mikael Finstad / #4401)
- @uppy/core,@uppy/locales,@uppy/provider-views: User feedback adding recursive folders take 2 (Mikael Finstad / #4399)

## 3.2.0

Released: 2023-04-04
Included in: Uppy v3.7.0

- @uppy/provider-views: fix race condition when adding folders (Mikael Finstad / #4384)
- @uppy/provider-views: UI: Use form attribite with a form in doc root to prevent outer form submit (Artur Paikin / #4283)

## 3.0.2

Released: 2022-10-24
Included in: Uppy v3.2.2

- @uppy/provider-views: Fix button and input inconsistent font and style (Artur Paikin / #4162)

## 3.0.1

Released: 2022-09-25
Included in: Uppy v3.1.0

- @uppy/audio,@uppy/aws-s3-multipart,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/companion,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/redux-dev-tools,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: add missing entries to changelog for individual packages (Antoine du Hamel / #4092)

## 3.0.0-beta.3

Released: 2022-08-16
Included in: Uppy v3.0.0-beta.5

- @uppy/provider-views: Reset filter input correctly in provider views (Merlijn Vos / #3978)
- @uppy/provider-views: core validateRestrictions: return error directly vs the result/reason obj (Artur Paikin / #3951)

## 2.1.2

Released: 2022-07-06
Included in: Uppy v2.12.2

- @uppy/provider-views: improve logging (Mikael Finstad / #3638)

## 2.1.1

Released: 2022-05-30
Included in: Uppy v2.11.0

- @uppy/provider-views: Add onKeyPress event handler to capture e.shiftKey, unavailable in onChange (Artur Paikin / #3768)

## 2.1.0

Released: 2022-05-14
Included in: Uppy v2.10.0

- @uppy/provider-views: refactor to ESM (Antoine du Hamel / #3715)

## 2.0.8

Released: 2022-03-16
Included in: Uppy v2.8.0

- @uppy/provider-views: provider-view: fix breadcrumbs (Artur Paikin / #3535)

## 2.0.7

Released: 2022-02-14
Included in: Uppy v2.5.0

- @uppy/companion-client,@uppy/companion,@uppy/provider-views,@uppy/robodog: Finishing touches on Companion dynamic Oauth (Renée Kooi / #2802)
- @uppy/provider-views: Unsplash: UI improvements (Artur Paikin / #3438)
## 3.0.0

Released: 2022-08-22
Included in: Uppy v3.0.0

- Switch to ESM
